;;
;; Copyright (C) 2013 Aleix Conchillo Flaque <aconchillo at gmail dot com>
;;
;; This file is part of guile-xmlrpc.
;;
;; guile-xmlrpc is free software; you can redistribute it and/or
;; modify it under the terms of the GNU Lesser General Public
;; License as published by the Free Software Foundation; either
;; version 3 of the License, or (at your option) any later version.
;;
;; guile-xmlrpc is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; Lesser General Public License for more details.
;;
;; You should have received a copy of the GNU Lesser General Public
;; License along with guile-xmlrpc; if not, write to the Free Software
;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
;; 02110-1301 USA
;;

(package (xmlrpc (0 2 0))
  (depends (srfi-1))
  (synopsis "XMLRPC implementation for Guile")
  (description
   "guile-xmlrpc is an XMLRPC module for Guile. Guile comes with the"
   "wonderful sxml module that allows XML document creation and"
   "parsing. guile-xmlrpc goes one step further and combines sxml with"
   "some macros and procedures that simplifies even more the creation"
   "and parsing of XMLRPC documents. It complies with the"
   "http://xmlrpc.com specification and is released under the LGPLv3.")
  (homepage "https://github.com/aconchillo/guile-xmlrpc")
  (libraries "xmlrpc.scm" "xmlrpc")
  (documentation "README" "COPYING" "COPYING.LESSER"))
